<?php
/**
 * @file
 */
namespace Drupal\important_information\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Component\Serialization\Json;
use Drupal\Core\Form\ConfigFormBase;

/**
 * Provides an Important Information block that floats above the site, hugging
 * the bottom of the viewport.
 *
 * @Block(
 *   id = "embedded_bottom",
 *   admin_label = @Translation("Important Information: Embedded Bottom"),
 *   category = @Translation("Important Information")
 * )
 */
class EmbeddedBottom extends BlockBase {
  /**
   * {@inheritdoc}
   */
  public function build() {
    
    // Load entity.
    $entities = \Drupal::entityTypeManager()->getStorage('ii_content')->loadByProperties(['type' => 'bottom']);

    foreach ($entities as $entity) {
      $important_information_value = $entity->get('field_ii_content_bottom')->value;
      $important_information_format = $entity->get('field_ii_content_bottom')->format;
      $full_size = $entity->get('field_full_size_bottom')->getString();
      $expandable = $entity->get('field_collapsible_bottom')->getString();
      $expand_value = $entity->get('field_collapsible_title_bottom')->value;
      $expand_format = $entity->get('field_collapsible_title_bottom')->format;

      $information = array(
        '#type' => 'processed_text',
        '#text' => $important_information_value,
        '#format' => $important_information_format,
      );

      // Format information via TPL
      $variables = array(
        '#type' => 'markup',
        '#theme' => 'embedded_bottom',
        '#information' => $information,
        '#attached' => array(
          'library' => array(
            'important_information/importantInformationBottom',
          ),
        ),
      );


      // Check for Modal
      if ($full_size == 1) {

        $link_url = Url::fromRoute('important_information.bottom');
        $link_url->setOptions([
          'attributes' => [
            'class' => ['use-ajax', 'button', 'button--small'],
            'data-dialog-type' => 'modal',
          ]
        ]);

        $variables['#modal'] =  array(
          '#type' => 'markup',
          '#markup' => Link::fromTextAndUrl(t('Full size'), $link_url)->toString(),
        );
        $variables['#attached']['library'][] = 'core/drupal.dialog.ajax';
      }

      // Check for Expandability
      if ($expandable == 1) {

        $expand_button_markup = array(
            '#type' => 'processed_text',
            '#text' => $expand_value,
            '#format' => $expand_format,
        );

        $variables['#expandable'] = TRUE;
        $variables['#default_expand_markup'] = $expand_button_markup;
        $variables['#attached']['library'][] = 'core/drupal.dialog.ajax';
      
        $variables['#attached']['drupalSettings']['important_information']['importantInformationEmbeddedBottom'] = array(
          'expandable' => TRUE,
          'expandMarkup' => render($expand_button_markup),
        );
      }
      else {
        $variables['#expandable'] = FALSE;
        $variables['#attached']['drupalSettings']['important_information']['importantInformationEmbeddedBottom'] = array(
            'expandable' => FALSE
        );
      }

      return $variables;

    }
  }
}   
