<?php
/**
 * @file
 */
namespace Drupal\important_information\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Component\Serialization\Json;

/**
 * Provides an Important Information block that floats above the site, hugging
 * the bottom of the viewport.
 *
 * @Block(
 *   id = "sidebar",
 *   admin_label = @Translation("Important Information: Sidebar"),
 *   category = @Translation("Important Information")
 * )
 */
class Sidebar extends BlockBase {
  /**
   * {@inheritdoc}
   */
  public function build() {

    // Load entities.
    $entities_sidebar = \Drupal::entityTypeManager()->getStorage('ii_content')->loadByProperties(['type' => 'sidebar']);
    $entities_bottom = \Drupal::entityTypeManager()->getStorage('ii_content')->loadByProperties(['type' => 'bottom']);

    foreach ($entities_sidebar as $entitySidebar) {
        $container_hide = $entitySidebar->get('field_hide_sidebar')->getString();
        $offset_bottom = $entitySidebar->get('field_offset_sidebar_bottom')->getString();
        $offset = $entitySidebar->get('field_offset_sidebar')->getString();
        $full_size = $entitySidebar->get('field_full_size_sidebar')->getString();
        $container_width = $entitySidebar->get('field_container_width_sidebar')->getString();
    }
  
    foreach ($entities_bottom as $entityBottom) {
        $important_information_value = $entityBottom->get('field_ii_content_bottom')->value;
        $important_information_format = $entityBottom->get('field_ii_content_bottom')->format;
    }

    $information = array(
        '#type' => 'processed_text',
        '#text' => $important_information_value,
        '#format' => $important_information_format,
      );

      // Format information via TPL
      $variables = array(
        '#type' => 'markup',
        '#theme' => 'sidebar',
        '#information' => $information,
        '#attached' => array(
          'library' => array(
            'important_information/importantInformationSidebar',
          ),
        ),
      );

      // Check for Modal
      if ($full_size == 1) {

        $link_url = Url::fromRoute('important_information.sidebar');
        $link_url->setOptions([
          'attributes' => [
            'class' => ['use-ajax', 'button', 'button--small'],
            'data-dialog-type' => 'modal',
          ]
        ]);

        $variables['#modal'] =  array(
          '#type' => 'markup',
          '#markup' => Link::fromTextAndUrl(t('Full size'), $link_url)->toString(),
        );
        $variables['#attached']['library'][] = 'core/drupal.dialog.ajax';
      }

      // Add block and module configuration to settings.
      $variables['#attached']['drupalSettings']['important_information']['importantInformationSidebar'] = array(
        'sidebarYOffset' => $offset,
        'containerWidth' => $container_width,
        'hide' => $container_hide ? $container_hide : FALSE,
        'offsetBottom' => $offset_bottom,
      );

      return $variables;

  }

}